# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ...types import mobile_phone_number_list_params, mobile_phone_number_update_params
from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from .messaging import (
    MessagingResource,
    AsyncMessagingResource,
    MessagingResourceWithRawResponse,
    AsyncMessagingResourceWithRawResponse,
    MessagingResourceWithStreamingResponse,
    AsyncMessagingResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from ..._base_client import AsyncPaginator, make_request_options
from ...types.mobile_phone_number import MobilePhoneNumber
from ...types.mobile_phone_number_update_response import MobilePhoneNumberUpdateResponse
from ...types.mobile_phone_number_retrieve_response import MobilePhoneNumberRetrieveResponse

__all__ = ["MobilePhoneNumbersResource", "AsyncMobilePhoneNumbersResource"]


class MobilePhoneNumbersResource(SyncAPIResource):
    @cached_property
    def messaging(self) -> MessagingResource:
        return MessagingResource(self._client)

    @cached_property
    def with_raw_response(self) -> MobilePhoneNumbersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return MobilePhoneNumbersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MobilePhoneNumbersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return MobilePhoneNumbersResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MobilePhoneNumberRetrieveResponse:
        """
        Retrieve a Mobile Phone Number

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v2/mobile_phone_numbers/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MobilePhoneNumberRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        call_forwarding: mobile_phone_number_update_params.CallForwarding | Omit = omit,
        call_recording: mobile_phone_number_update_params.CallRecording | Omit = omit,
        caller_id_name_enabled: bool | Omit = omit,
        cnam_listing: mobile_phone_number_update_params.CnamListing | Omit = omit,
        connection_id: Optional[str] | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        inbound: mobile_phone_number_update_params.Inbound | Omit = omit,
        inbound_call_screening: Literal["disabled", "reject_calls", "flag_calls"] | Omit = omit,
        noise_suppression: bool | Omit = omit,
        outbound: mobile_phone_number_update_params.Outbound | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MobilePhoneNumberUpdateResponse:
        """
        Update a Mobile Phone Number

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._patch(
            f"/v2/mobile_phone_numbers/{id}",
            body=maybe_transform(
                {
                    "call_forwarding": call_forwarding,
                    "call_recording": call_recording,
                    "caller_id_name_enabled": caller_id_name_enabled,
                    "cnam_listing": cnam_listing,
                    "connection_id": connection_id,
                    "customer_reference": customer_reference,
                    "inbound": inbound,
                    "inbound_call_screening": inbound_call_screening,
                    "noise_suppression": noise_suppression,
                    "outbound": outbound,
                    "tags": tags,
                },
                mobile_phone_number_update_params.MobilePhoneNumberUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MobilePhoneNumberUpdateResponse,
        )

    def list(
        self,
        *,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[MobilePhoneNumber]:
        """
        List Mobile Phone Numbers

        Args:
          page_number: The page number to load

          page_size: The size of the page

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v2/mobile_phone_numbers",
            page=SyncDefaultFlatPagination[MobilePhoneNumber],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    mobile_phone_number_list_params.MobilePhoneNumberListParams,
                ),
            ),
            model=MobilePhoneNumber,
        )


class AsyncMobilePhoneNumbersResource(AsyncAPIResource):
    @cached_property
    def messaging(self) -> AsyncMessagingResource:
        return AsyncMessagingResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMobilePhoneNumbersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMobilePhoneNumbersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMobilePhoneNumbersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncMobilePhoneNumbersResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MobilePhoneNumberRetrieveResponse:
        """
        Retrieve a Mobile Phone Number

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v2/mobile_phone_numbers/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MobilePhoneNumberRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        call_forwarding: mobile_phone_number_update_params.CallForwarding | Omit = omit,
        call_recording: mobile_phone_number_update_params.CallRecording | Omit = omit,
        caller_id_name_enabled: bool | Omit = omit,
        cnam_listing: mobile_phone_number_update_params.CnamListing | Omit = omit,
        connection_id: Optional[str] | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        inbound: mobile_phone_number_update_params.Inbound | Omit = omit,
        inbound_call_screening: Literal["disabled", "reject_calls", "flag_calls"] | Omit = omit,
        noise_suppression: bool | Omit = omit,
        outbound: mobile_phone_number_update_params.Outbound | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MobilePhoneNumberUpdateResponse:
        """
        Update a Mobile Phone Number

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._patch(
            f"/v2/mobile_phone_numbers/{id}",
            body=await async_maybe_transform(
                {
                    "call_forwarding": call_forwarding,
                    "call_recording": call_recording,
                    "caller_id_name_enabled": caller_id_name_enabled,
                    "cnam_listing": cnam_listing,
                    "connection_id": connection_id,
                    "customer_reference": customer_reference,
                    "inbound": inbound,
                    "inbound_call_screening": inbound_call_screening,
                    "noise_suppression": noise_suppression,
                    "outbound": outbound,
                    "tags": tags,
                },
                mobile_phone_number_update_params.MobilePhoneNumberUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MobilePhoneNumberUpdateResponse,
        )

    def list(
        self,
        *,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[MobilePhoneNumber, AsyncDefaultFlatPagination[MobilePhoneNumber]]:
        """
        List Mobile Phone Numbers

        Args:
          page_number: The page number to load

          page_size: The size of the page

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v2/mobile_phone_numbers",
            page=AsyncDefaultFlatPagination[MobilePhoneNumber],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    mobile_phone_number_list_params.MobilePhoneNumberListParams,
                ),
            ),
            model=MobilePhoneNumber,
        )


class MobilePhoneNumbersResourceWithRawResponse:
    def __init__(self, mobile_phone_numbers: MobilePhoneNumbersResource) -> None:
        self._mobile_phone_numbers = mobile_phone_numbers

        self.retrieve = to_raw_response_wrapper(
            mobile_phone_numbers.retrieve,
        )
        self.update = to_raw_response_wrapper(
            mobile_phone_numbers.update,
        )
        self.list = to_raw_response_wrapper(
            mobile_phone_numbers.list,
        )

    @cached_property
    def messaging(self) -> MessagingResourceWithRawResponse:
        return MessagingResourceWithRawResponse(self._mobile_phone_numbers.messaging)


class AsyncMobilePhoneNumbersResourceWithRawResponse:
    def __init__(self, mobile_phone_numbers: AsyncMobilePhoneNumbersResource) -> None:
        self._mobile_phone_numbers = mobile_phone_numbers

        self.retrieve = async_to_raw_response_wrapper(
            mobile_phone_numbers.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            mobile_phone_numbers.update,
        )
        self.list = async_to_raw_response_wrapper(
            mobile_phone_numbers.list,
        )

    @cached_property
    def messaging(self) -> AsyncMessagingResourceWithRawResponse:
        return AsyncMessagingResourceWithRawResponse(self._mobile_phone_numbers.messaging)


class MobilePhoneNumbersResourceWithStreamingResponse:
    def __init__(self, mobile_phone_numbers: MobilePhoneNumbersResource) -> None:
        self._mobile_phone_numbers = mobile_phone_numbers

        self.retrieve = to_streamed_response_wrapper(
            mobile_phone_numbers.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            mobile_phone_numbers.update,
        )
        self.list = to_streamed_response_wrapper(
            mobile_phone_numbers.list,
        )

    @cached_property
    def messaging(self) -> MessagingResourceWithStreamingResponse:
        return MessagingResourceWithStreamingResponse(self._mobile_phone_numbers.messaging)


class AsyncMobilePhoneNumbersResourceWithStreamingResponse:
    def __init__(self, mobile_phone_numbers: AsyncMobilePhoneNumbersResource) -> None:
        self._mobile_phone_numbers = mobile_phone_numbers

        self.retrieve = async_to_streamed_response_wrapper(
            mobile_phone_numbers.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            mobile_phone_numbers.update,
        )
        self.list = async_to_streamed_response_wrapper(
            mobile_phone_numbers.list,
        )

    @cached_property
    def messaging(self) -> AsyncMessagingResourceWithStreamingResponse:
        return AsyncMessagingResourceWithStreamingResponse(self._mobile_phone_numbers.messaging)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["TextToSpeechListVoicesResponse", "Voice"]


class Voice(BaseModel):
    id: Optional[str] = None

    accent: Optional[str] = None

    age: Optional[str] = None

    gender: Optional[str] = None

    label: Optional[str] = None

    language: Optional[str] = None

    name: Optional[str] = None

    provider: Optional[str] = None


class TextToSpeechListVoicesResponse(BaseModel):
    voices: Optional[List[Voice]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_enable_params import ActionEnableParams as ActionEnableParams
from .action_enable_response import ActionEnableResponse as ActionEnableResponse
from .action_disable_response import ActionDisableResponse as ActionDisableResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["TextToSpeechListVoicesParams"]


class TextToSpeechListVoicesParams(TypedDict, total=False):
    elevenlabs_api_key_ref: str
    """Reference to your ElevenLabs API key stored in the Telnyx Portal"""

    provider: Literal["aws", "azure", "elevenlabs", "telnyx"]
    """Filter voices by provider"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .recording_response_data import RecordingResponseData

__all__ = ["RecordingRetrieveResponse"]


class RecordingRetrieveResponse(BaseModel):
    data: Optional[RecordingResponseData] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ...._models import BaseModel
from .fine_tuning_job import FineTuningJob

__all__ = ["JobListResponse"]


class JobListResponse(BaseModel):
    data: List[FineTuningJob]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ai import (
    AIResource,
    AsyncAIResource,
    AIResourceWithRawResponse,
    AsyncAIResourceWithRawResponse,
    AIResourceWithStreamingResponse,
    AsyncAIResourceWithStreamingResponse,
)
from .chat import (
    ChatResource,
    AsyncChatResource,
    ChatResourceWithRawResponse,
    AsyncChatResourceWithRawResponse,
    ChatResourceWithStreamingResponse,
    AsyncChatResourceWithStreamingResponse,
)
from .audio import (
    AudioResource,
    AsyncAudioResource,
    AudioResourceWithRawResponse,
    AsyncAudioResourceWithRawResponse,
    AudioResourceWithStreamingResponse,
    AsyncAudioResourceWithStreamingResponse,
)
from .openai import (
    OpenAIResource,
    AsyncOpenAIResource,
    OpenAIResourceWithRawResponse,
    AsyncOpenAIResourceWithRawResponse,
    OpenAIResourceWithStreamingResponse,
    AsyncOpenAIResourceWithStreamingResponse,
)
from .clusters import (
    ClustersResource,
    AsyncClustersResource,
    ClustersResourceWithRawResponse,
    AsyncClustersResourceWithRawResponse,
    ClustersResourceWithStreamingResponse,
    AsyncClustersResourceWithStreamingResponse,
)
from .missions import (
    MissionsResource,
    AsyncMissionsResource,
    MissionsResourceWithRawResponse,
    AsyncMissionsResourceWithRawResponse,
    MissionsResourceWithStreamingResponse,
    AsyncMissionsResourceWithStreamingResponse,
)
from .assistants import (
    AssistantsResource,
    AsyncAssistantsResource,
    AssistantsResourceWithRawResponse,
    AsyncAssistantsResourceWithRawResponse,
    AssistantsResourceWithStreamingResponse,
    AsyncAssistantsResourceWithStreamingResponse,
)
from .embeddings import (
    EmbeddingsResource,
    AsyncEmbeddingsResource,
    EmbeddingsResourceWithRawResponse,
    AsyncEmbeddingsResourceWithRawResponse,
    EmbeddingsResourceWithStreamingResponse,
    AsyncEmbeddingsResourceWithStreamingResponse,
)
from .fine_tuning import (
    FineTuningResource,
    AsyncFineTuningResource,
    FineTuningResourceWithRawResponse,
    AsyncFineTuningResourceWithRawResponse,
    FineTuningResourceWithStreamingResponse,
    AsyncFineTuningResourceWithStreamingResponse,
)
from .mcp_servers import (
    McpServersResource,
    AsyncMcpServersResource,
    McpServersResourceWithRawResponse,
    AsyncMcpServersResourceWithRawResponse,
    McpServersResourceWithStreamingResponse,
    AsyncMcpServersResourceWithStreamingResponse,
)
from .integrations import (
    IntegrationsResource,
    AsyncIntegrationsResource,
    IntegrationsResourceWithRawResponse,
    AsyncIntegrationsResourceWithRawResponse,
    IntegrationsResourceWithStreamingResponse,
    AsyncIntegrationsResourceWithStreamingResponse,
)
from .conversations import (
    ConversationsResource,
    AsyncConversationsResource,
    ConversationsResourceWithRawResponse,
    AsyncConversationsResourceWithRawResponse,
    ConversationsResourceWithStreamingResponse,
    AsyncConversationsResourceWithStreamingResponse,
)

__all__ = [
    "AssistantsResource",
    "AsyncAssistantsResource",
    "AssistantsResourceWithRawResponse",
    "AsyncAssistantsResourceWithRawResponse",
    "AssistantsResourceWithStreamingResponse",
    "AsyncAssistantsResourceWithStreamingResponse",
    "AudioResource",
    "AsyncAudioResource",
    "AudioResourceWithRawResponse",
    "AsyncAudioResourceWithRawResponse",
    "AudioResourceWithStreamingResponse",
    "AsyncAudioResourceWithStreamingResponse",
    "ChatResource",
    "AsyncChatResource",
    "ChatResourceWithRawResponse",
    "AsyncChatResourceWithRawResponse",
    "ChatResourceWithStreamingResponse",
    "AsyncChatResourceWithStreamingResponse",
    "ClustersResource",
    "AsyncClustersResource",
    "ClustersResourceWithRawResponse",
    "AsyncClustersResourceWithRawResponse",
    "ClustersResourceWithStreamingResponse",
    "AsyncClustersResourceWithStreamingResponse",
    "ConversationsResource",
    "AsyncConversationsResource",
    "ConversationsResourceWithRawResponse",
    "AsyncConversationsResourceWithRawResponse",
    "ConversationsResourceWithStreamingResponse",
    "AsyncConversationsResourceWithStreamingResponse",
    "EmbeddingsResource",
    "AsyncEmbeddingsResource",
    "EmbeddingsResourceWithRawResponse",
    "AsyncEmbeddingsResourceWithRawResponse",
    "EmbeddingsResourceWithStreamingResponse",
    "AsyncEmbeddingsResourceWithStreamingResponse",
    "FineTuningResource",
    "AsyncFineTuningResource",
    "FineTuningResourceWithRawResponse",
    "AsyncFineTuningResourceWithRawResponse",
    "FineTuningResourceWithStreamingResponse",
    "AsyncFineTuningResourceWithStreamingResponse",
    "IntegrationsResource",
    "AsyncIntegrationsResource",
    "IntegrationsResourceWithRawResponse",
    "AsyncIntegrationsResourceWithRawResponse",
    "IntegrationsResourceWithStreamingResponse",
    "AsyncIntegrationsResourceWithStreamingResponse",
    "McpServersResource",
    "AsyncMcpServersResource",
    "McpServersResourceWithRawResponse",
    "AsyncMcpServersResourceWithRawResponse",
    "McpServersResourceWithStreamingResponse",
    "AsyncMcpServersResourceWithStreamingResponse",
    "MissionsResource",
    "AsyncMissionsResource",
    "MissionsResourceWithRawResponse",
    "AsyncMissionsResourceWithRawResponse",
    "MissionsResourceWithStreamingResponse",
    "AsyncMissionsResourceWithStreamingResponse",
    "OpenAIResource",
    "AsyncOpenAIResource",
    "OpenAIResourceWithRawResponse",
    "AsyncOpenAIResourceWithRawResponse",
    "OpenAIResourceWithStreamingResponse",
    "AsyncOpenAIResourceWithStreamingResponse",
    "AIResource",
    "AsyncAIResource",
    "AIResourceWithRawResponse",
    "AsyncAIResourceWithRawResponse",
    "AIResourceWithStreamingResponse",
    "AsyncAIResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_fork_stopped import CallForkStopped

__all__ = ["CallForkStoppedWebhookEvent"]


class CallForkStoppedWebhookEvent(BaseModel):
    data: Optional[CallForkStopped] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.messaging import (
    RcInviteTestNumberResponse,
    RcListBulkCapabilitiesResponse,
    RcRetrieveCapabilitiesResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRcs:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_invite_test_number(self, client: Telnyx) -> None:
        rc = client.messaging.rcs.invite_test_number(
            phone_number="phone_number",
            id="id",
        )
        assert_matches_type(RcInviteTestNumberResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_invite_test_number(self, client: Telnyx) -> None:
        response = client.messaging.rcs.with_raw_response.invite_test_number(
            phone_number="phone_number",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        rc = response.parse()
        assert_matches_type(RcInviteTestNumberResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_invite_test_number(self, client: Telnyx) -> None:
        with client.messaging.rcs.with_streaming_response.invite_test_number(
            phone_number="phone_number",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            rc = response.parse()
            assert_matches_type(RcInviteTestNumberResponse, rc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_invite_test_number(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.messaging.rcs.with_raw_response.invite_test_number(
                phone_number="phone_number",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `phone_number` but received ''"):
            client.messaging.rcs.with_raw_response.invite_test_number(
                phone_number="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_bulk_capabilities(self, client: Telnyx) -> None:
        rc = client.messaging.rcs.list_bulk_capabilities(
            agent_id="TestAgent",
            phone_numbers=["+13125551234"],
        )
        assert_matches_type(RcListBulkCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_bulk_capabilities(self, client: Telnyx) -> None:
        response = client.messaging.rcs.with_raw_response.list_bulk_capabilities(
            agent_id="TestAgent",
            phone_numbers=["+13125551234"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        rc = response.parse()
        assert_matches_type(RcListBulkCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_bulk_capabilities(self, client: Telnyx) -> None:
        with client.messaging.rcs.with_streaming_response.list_bulk_capabilities(
            agent_id="TestAgent",
            phone_numbers=["+13125551234"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            rc = response.parse()
            assert_matches_type(RcListBulkCapabilitiesResponse, rc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_capabilities(self, client: Telnyx) -> None:
        rc = client.messaging.rcs.retrieve_capabilities(
            phone_number="phone_number",
            agent_id="agent_id",
        )
        assert_matches_type(RcRetrieveCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_capabilities(self, client: Telnyx) -> None:
        response = client.messaging.rcs.with_raw_response.retrieve_capabilities(
            phone_number="phone_number",
            agent_id="agent_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        rc = response.parse()
        assert_matches_type(RcRetrieveCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_capabilities(self, client: Telnyx) -> None:
        with client.messaging.rcs.with_streaming_response.retrieve_capabilities(
            phone_number="phone_number",
            agent_id="agent_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            rc = response.parse()
            assert_matches_type(RcRetrieveCapabilitiesResponse, rc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve_capabilities(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `agent_id` but received ''"):
            client.messaging.rcs.with_raw_response.retrieve_capabilities(
                phone_number="phone_number",
                agent_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `phone_number` but received ''"):
            client.messaging.rcs.with_raw_response.retrieve_capabilities(
                phone_number="",
                agent_id="agent_id",
            )


class TestAsyncRcs:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_invite_test_number(self, async_client: AsyncTelnyx) -> None:
        rc = await async_client.messaging.rcs.invite_test_number(
            phone_number="phone_number",
            id="id",
        )
        assert_matches_type(RcInviteTestNumberResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_invite_test_number(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging.rcs.with_raw_response.invite_test_number(
            phone_number="phone_number",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        rc = await response.parse()
        assert_matches_type(RcInviteTestNumberResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_invite_test_number(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging.rcs.with_streaming_response.invite_test_number(
            phone_number="phone_number",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            rc = await response.parse()
            assert_matches_type(RcInviteTestNumberResponse, rc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_invite_test_number(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.messaging.rcs.with_raw_response.invite_test_number(
                phone_number="phone_number",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `phone_number` but received ''"):
            await async_client.messaging.rcs.with_raw_response.invite_test_number(
                phone_number="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_bulk_capabilities(self, async_client: AsyncTelnyx) -> None:
        rc = await async_client.messaging.rcs.list_bulk_capabilities(
            agent_id="TestAgent",
            phone_numbers=["+13125551234"],
        )
        assert_matches_type(RcListBulkCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_bulk_capabilities(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging.rcs.with_raw_response.list_bulk_capabilities(
            agent_id="TestAgent",
            phone_numbers=["+13125551234"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        rc = await response.parse()
        assert_matches_type(RcListBulkCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_bulk_capabilities(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging.rcs.with_streaming_response.list_bulk_capabilities(
            agent_id="TestAgent",
            phone_numbers=["+13125551234"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            rc = await response.parse()
            assert_matches_type(RcListBulkCapabilitiesResponse, rc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_capabilities(self, async_client: AsyncTelnyx) -> None:
        rc = await async_client.messaging.rcs.retrieve_capabilities(
            phone_number="phone_number",
            agent_id="agent_id",
        )
        assert_matches_type(RcRetrieveCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_capabilities(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging.rcs.with_raw_response.retrieve_capabilities(
            phone_number="phone_number",
            agent_id="agent_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        rc = await response.parse()
        assert_matches_type(RcRetrieveCapabilitiesResponse, rc, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_capabilities(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging.rcs.with_streaming_response.retrieve_capabilities(
            phone_number="phone_number",
            agent_id="agent_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            rc = await response.parse()
            assert_matches_type(RcRetrieveCapabilitiesResponse, rc, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve_capabilities(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `agent_id` but received ''"):
            await async_client.messaging.rcs.with_raw_response.retrieve_capabilities(
                phone_number="phone_number",
                agent_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `phone_number` but received ''"):
            await async_client.messaging.rcs.with_raw_response.retrieve_capabilities(
                phone_number="",
                agent_id="agent_id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SetiRetrieveBlackBoxTestResultsParams", "Filter"]


class SetiRetrieveBlackBoxTestResultsParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style). Originally: filter[product]"""


class Filter(TypedDict, total=False):
    """Consolidated filter parameter (deepObject style). Originally: filter[product]"""

    product: str
    """Filter results for a specific product."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, TypedDict

__all__ = ["TransferToolParam", "Transfer", "TransferTarget"]


class TransferTarget(TypedDict, total=False):
    name: str
    """The name of the target."""

    to: str
    """The destination number or SIP URI of the call."""


_TransferReservedKeywords = TypedDict(
    "_TransferReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class Transfer(_TransferReservedKeywords, total=False):
    targets: Required[Iterable[TransferTarget]]
    """The different possible targets of the transfer.

    The assistant will be able to choose one of the targets to transfer the call to.
    """


class TransferToolParam(TypedDict, total=False):
    transfer: Required[Transfer]

    type: Required[Literal["transfer"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_list_params import ActionListParams as ActionListParams
from .sim_card_group_action import SimCardGroupAction as SimCardGroupAction
from .action_retrieve_response import ActionRetrieveResponse as ActionRetrieveResponse
from .action_set_wireless_blocklist_params import ActionSetWirelessBlocklistParams as ActionSetWirelessBlocklistParams
from .action_set_wireless_blocklist_response import (
    ActionSetWirelessBlocklistResponse as ActionSetWirelessBlocklistResponse,
)
from .action_remove_wireless_blocklist_response import (
    ActionRemoveWirelessBlocklistResponse as ActionRemoveWirelessBlocklistResponse,
)
from .action_set_private_wireless_gateway_params import (
    ActionSetPrivateWirelessGatewayParams as ActionSetPrivateWirelessGatewayParams,
)
from .action_set_private_wireless_gateway_response import (
    ActionSetPrivateWirelessGatewayResponse as ActionSetPrivateWirelessGatewayResponse,
)
from .action_remove_private_wireless_gateway_response import (
    ActionRemovePrivateWirelessGatewayResponse as ActionRemovePrivateWirelessGatewayResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from ..types import requirement_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.requirement_list_response import RequirementListResponse
from ..types.requirement_retrieve_response import RequirementRetrieveResponse

__all__ = ["RequirementsResource", "AsyncRequirementsResource"]


class RequirementsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RequirementsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return RequirementsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RequirementsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return RequirementsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RequirementRetrieveResponse:
        """
        Retrieve a document requirement record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/requirements/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RequirementRetrieveResponse,
        )

    def list(
        self,
        *,
        filter: requirement_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        sort: List[
            Literal[
                "created_at",
                "updated_at",
                "country_code",
                "phone_number_type",
                "-created_at",
                "-updated_at",
                "-country_code",
                "-phone_number_type",
            ]
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[RequirementListResponse]:
        """
        List all requirements with filtering, sorting, and pagination

        Args:
          filter:
              Consolidated filter parameter for requirements (deepObject style). Originally:
              filter[country_code], filter[phone_number_type], filter[action]

          sort:
              Consolidated sort parameter for requirements (deepObject style). Originally:
              sort[]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/requirements",
            page=SyncDefaultFlatPagination[RequirementListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                        "sort": sort,
                    },
                    requirement_list_params.RequirementListParams,
                ),
            ),
            model=RequirementListResponse,
        )


class AsyncRequirementsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRequirementsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRequirementsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRequirementsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncRequirementsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RequirementRetrieveResponse:
        """
        Retrieve a document requirement record

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/requirements/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RequirementRetrieveResponse,
        )

    def list(
        self,
        *,
        filter: requirement_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        sort: List[
            Literal[
                "created_at",
                "updated_at",
                "country_code",
                "phone_number_type",
                "-created_at",
                "-updated_at",
                "-country_code",
                "-phone_number_type",
            ]
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[RequirementListResponse, AsyncDefaultFlatPagination[RequirementListResponse]]:
        """
        List all requirements with filtering, sorting, and pagination

        Args:
          filter:
              Consolidated filter parameter for requirements (deepObject style). Originally:
              filter[country_code], filter[phone_number_type], filter[action]

          sort:
              Consolidated sort parameter for requirements (deepObject style). Originally:
              sort[]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/requirements",
            page=AsyncDefaultFlatPagination[RequirementListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                        "sort": sort,
                    },
                    requirement_list_params.RequirementListParams,
                ),
            ),
            model=RequirementListResponse,
        )


class RequirementsResourceWithRawResponse:
    def __init__(self, requirements: RequirementsResource) -> None:
        self._requirements = requirements

        self.retrieve = to_raw_response_wrapper(
            requirements.retrieve,
        )
        self.list = to_raw_response_wrapper(
            requirements.list,
        )


class AsyncRequirementsResourceWithRawResponse:
    def __init__(self, requirements: AsyncRequirementsResource) -> None:
        self._requirements = requirements

        self.retrieve = async_to_raw_response_wrapper(
            requirements.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            requirements.list,
        )


class RequirementsResourceWithStreamingResponse:
    def __init__(self, requirements: RequirementsResource) -> None:
        self._requirements = requirements

        self.retrieve = to_streamed_response_wrapper(
            requirements.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            requirements.list,
        )


class AsyncRequirementsResourceWithStreamingResponse:
    def __init__(self, requirements: AsyncRequirementsResource) -> None:
        self._requirements = requirements

        self.retrieve = async_to_streamed_response_wrapper(
            requirements.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            requirements.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_ai_gather_ended import CallAIGatherEnded

__all__ = ["CallAIGatherEndedWebhookEvent"]


class CallAIGatherEndedWebhookEvent(BaseModel):
    data: Optional[CallAIGatherEnded] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["ActionVerifyOwnershipResponse", "Data", "DataFound"]


class DataFound(BaseModel):
    id: Optional[str] = None
    """Identifies the resource."""

    number_val_e164: Optional[str] = None
    """The phone number in E.164 format"""


class Data(BaseModel):
    found: Optional[List[DataFound]] = None
    """The list of phone numbers which you own and are in an editable state"""

    not_found: Optional[List[str]] = None
    """Phone numbers that are not found in the account"""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""


class ActionVerifyOwnershipResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["RcsContentInfo"]


class RcsContentInfo(BaseModel):
    file_url: str
    """Publicly reachable URL of the file."""

    force_refresh: Optional[bool] = None
    """If set the URL content will not be cached."""

    thumbnail_url: Optional[str] = None
    """Publicly reachable URL of the thumbnail. Maximum size of 100 kB."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["AssistantDeleteResponse"]


class AssistantDeleteResponse(BaseModel):
    """
    Aligns with the OpenAI API:
    https://platform.openai.com/docs/api-reference/assistants/deleteAssistant
    """

    id: str

    deleted: bool

    object: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from telnyx.types.porting_orders import (
    ActionRequirementListResponse,
    ActionRequirementInitiateResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestActionRequirements:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        action_requirement = client.porting_orders.action_requirements.list(
            porting_order_id="porting_order_id",
        )
        assert_matches_type(
            SyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        action_requirement = client.porting_orders.action_requirements.list(
            porting_order_id="porting_order_id",
            filter={
                "id": ["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
                "action_type": "au_id_verification",
                "requirement_type_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                "status": "created",
            },
            page_number=0,
            page_size=0,
            sort={"value": "created_at"},
        )
        assert_matches_type(
            SyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.porting_orders.action_requirements.with_raw_response.list(
            porting_order_id="porting_order_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action_requirement = response.parse()
        assert_matches_type(
            SyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.porting_orders.action_requirements.with_streaming_response.list(
            porting_order_id="porting_order_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action_requirement = response.parse()
            assert_matches_type(
                SyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            client.porting_orders.action_requirements.with_raw_response.list(
                porting_order_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_initiate(self, client: Telnyx) -> None:
        action_requirement = client.porting_orders.action_requirements.initiate(
            id="id",
            porting_order_id="porting_order_id",
            params={
                "first_name": "John",
                "last_name": "Doe",
            },
        )
        assert_matches_type(ActionRequirementInitiateResponse, action_requirement, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_initiate(self, client: Telnyx) -> None:
        response = client.porting_orders.action_requirements.with_raw_response.initiate(
            id="id",
            porting_order_id="porting_order_id",
            params={
                "first_name": "John",
                "last_name": "Doe",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action_requirement = response.parse()
        assert_matches_type(ActionRequirementInitiateResponse, action_requirement, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_initiate(self, client: Telnyx) -> None:
        with client.porting_orders.action_requirements.with_streaming_response.initiate(
            id="id",
            porting_order_id="porting_order_id",
            params={
                "first_name": "John",
                "last_name": "Doe",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action_requirement = response.parse()
            assert_matches_type(ActionRequirementInitiateResponse, action_requirement, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_initiate(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            client.porting_orders.action_requirements.with_raw_response.initiate(
                id="id",
                porting_order_id="",
                params={
                    "first_name": "John",
                    "last_name": "Doe",
                },
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.porting_orders.action_requirements.with_raw_response.initiate(
                id="",
                porting_order_id="porting_order_id",
                params={
                    "first_name": "John",
                    "last_name": "Doe",
                },
            )


class TestAsyncActionRequirements:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        action_requirement = await async_client.porting_orders.action_requirements.list(
            porting_order_id="porting_order_id",
        )
        assert_matches_type(
            AsyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action_requirement = await async_client.porting_orders.action_requirements.list(
            porting_order_id="porting_order_id",
            filter={
                "id": ["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
                "action_type": "au_id_verification",
                "requirement_type_id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                "status": "created",
            },
            page_number=0,
            page_size=0,
            sort={"value": "created_at"},
        )
        assert_matches_type(
            AsyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.porting_orders.action_requirements.with_raw_response.list(
            porting_order_id="porting_order_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action_requirement = await response.parse()
        assert_matches_type(
            AsyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.porting_orders.action_requirements.with_streaming_response.list(
            porting_order_id="porting_order_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action_requirement = await response.parse()
            assert_matches_type(
                AsyncDefaultFlatPagination[ActionRequirementListResponse], action_requirement, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            await async_client.porting_orders.action_requirements.with_raw_response.list(
                porting_order_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_initiate(self, async_client: AsyncTelnyx) -> None:
        action_requirement = await async_client.porting_orders.action_requirements.initiate(
            id="id",
            porting_order_id="porting_order_id",
            params={
                "first_name": "John",
                "last_name": "Doe",
            },
        )
        assert_matches_type(ActionRequirementInitiateResponse, action_requirement, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_initiate(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.porting_orders.action_requirements.with_raw_response.initiate(
            id="id",
            porting_order_id="porting_order_id",
            params={
                "first_name": "John",
                "last_name": "Doe",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action_requirement = await response.parse()
        assert_matches_type(ActionRequirementInitiateResponse, action_requirement, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_initiate(self, async_client: AsyncTelnyx) -> None:
        async with async_client.porting_orders.action_requirements.with_streaming_response.initiate(
            id="id",
            porting_order_id="porting_order_id",
            params={
                "first_name": "John",
                "last_name": "Doe",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action_requirement = await response.parse()
            assert_matches_type(ActionRequirementInitiateResponse, action_requirement, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_initiate(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `porting_order_id` but received ''"):
            await async_client.porting_orders.action_requirements.with_raw_response.initiate(
                id="id",
                porting_order_id="",
                params={
                    "first_name": "John",
                    "last_name": "Doe",
                },
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.porting_orders.action_requirements.with_raw_response.initiate(
                id="",
                porting_order_id="porting_order_id",
                params={
                    "first_name": "John",
                    "last_name": "Doe",
                },
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_control_application import CallControlApplication

__all__ = ["CallControlApplicationUpdateResponse"]


class CallControlApplicationUpdateResponse(BaseModel):
    data: Optional[CallControlApplication] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["RegionListResponse", "Data"]


class Data(BaseModel):
    code: Optional[str] = None
    """A code for the region."""

    created_at: Optional[str] = None
    """ISO 8601 formatted date-time indicating when the resource was created."""

    name: Optional[str] = None
    """A name for the region."""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    supported_interfaces: Optional[List[str]] = None
    """List of interface types supported in this region."""

    updated_at: Optional[str] = None
    """ISO 8601 formatted date-time indicating when the resource was updated."""


class RegionListResponse(BaseModel):
    data: Optional[List[Data]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.addresses import action_validate_params, action_accept_suggestions_params
from ...types.addresses.action_validate_response import ActionValidateResponse
from ...types.addresses.action_accept_suggestions_response import ActionAcceptSuggestionsResponse

__all__ = ["ActionsResource", "AsyncActionsResource"]


class ActionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ActionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return ActionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ActionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return ActionsResourceWithStreamingResponse(self)

    def accept_suggestions(
        self,
        address_uuid: str,
        *,
        id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ActionAcceptSuggestionsResponse:
        """
        Accepts this address suggestion as a new emergency address for Operator Connect
        and finishes the uploads of the numbers associated with it to Microsoft.

        Args:
          id: The ID of the address.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not address_uuid:
            raise ValueError(f"Expected a non-empty value for `address_uuid` but received {address_uuid!r}")
        return self._post(
            f"/addresses/{address_uuid}/actions/accept_suggestions",
            body=maybe_transform({"id": id}, action_accept_suggestions_params.ActionAcceptSuggestionsParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ActionAcceptSuggestionsResponse,
        )

    def validate(
        self,
        *,
        country_code: str,
        postal_code: str,
        street_address: str,
        administrative_area: str | Omit = omit,
        extended_address: str | Omit = omit,
        locality: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ActionValidateResponse:
        """
        Validates an address for emergency services.

        Args:
          country_code: The two-character (ISO 3166-1 alpha-2) country code of the address.

          postal_code: The postal code of the address.

          street_address: The primary street address information about the address.

          administrative_area: The locality of the address. For US addresses, this corresponds to the state of
              the address.

          extended_address: Additional street address information about the address such as, but not limited
              to, unit number or apartment number.

          locality: The locality of the address. For US addresses, this corresponds to the city of
              the address.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/addresses/actions/validate",
            body=maybe_transform(
                {
                    "country_code": country_code,
                    "postal_code": postal_code,
                    "street_address": street_address,
                    "administrative_area": administrative_area,
                    "extended_address": extended_address,
                    "locality": locality,
                },
                action_validate_params.ActionValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ActionValidateResponse,
        )


class AsyncActionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncActionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncActionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncActionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncActionsResourceWithStreamingResponse(self)

    async def accept_suggestions(
        self,
        address_uuid: str,
        *,
        id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ActionAcceptSuggestionsResponse:
        """
        Accepts this address suggestion as a new emergency address for Operator Connect
        and finishes the uploads of the numbers associated with it to Microsoft.

        Args:
          id: The ID of the address.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not address_uuid:
            raise ValueError(f"Expected a non-empty value for `address_uuid` but received {address_uuid!r}")
        return await self._post(
            f"/addresses/{address_uuid}/actions/accept_suggestions",
            body=await async_maybe_transform(
                {"id": id}, action_accept_suggestions_params.ActionAcceptSuggestionsParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ActionAcceptSuggestionsResponse,
        )

    async def validate(
        self,
        *,
        country_code: str,
        postal_code: str,
        street_address: str,
        administrative_area: str | Omit = omit,
        extended_address: str | Omit = omit,
        locality: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ActionValidateResponse:
        """
        Validates an address for emergency services.

        Args:
          country_code: The two-character (ISO 3166-1 alpha-2) country code of the address.

          postal_code: The postal code of the address.

          street_address: The primary street address information about the address.

          administrative_area: The locality of the address. For US addresses, this corresponds to the state of
              the address.

          extended_address: Additional street address information about the address such as, but not limited
              to, unit number or apartment number.

          locality: The locality of the address. For US addresses, this corresponds to the city of
              the address.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/addresses/actions/validate",
            body=await async_maybe_transform(
                {
                    "country_code": country_code,
                    "postal_code": postal_code,
                    "street_address": street_address,
                    "administrative_area": administrative_area,
                    "extended_address": extended_address,
                    "locality": locality,
                },
                action_validate_params.ActionValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ActionValidateResponse,
        )


class ActionsResourceWithRawResponse:
    def __init__(self, actions: ActionsResource) -> None:
        self._actions = actions

        self.accept_suggestions = to_raw_response_wrapper(
            actions.accept_suggestions,
        )
        self.validate = to_raw_response_wrapper(
            actions.validate,
        )


class AsyncActionsResourceWithRawResponse:
    def __init__(self, actions: AsyncActionsResource) -> None:
        self._actions = actions

        self.accept_suggestions = async_to_raw_response_wrapper(
            actions.accept_suggestions,
        )
        self.validate = async_to_raw_response_wrapper(
            actions.validate,
        )


class ActionsResourceWithStreamingResponse:
    def __init__(self, actions: ActionsResource) -> None:
        self._actions = actions

        self.accept_suggestions = to_streamed_response_wrapper(
            actions.accept_suggestions,
        )
        self.validate = to_streamed_response_wrapper(
            actions.validate,
        )


class AsyncActionsResourceWithStreamingResponse:
    def __init__(self, actions: AsyncActionsResource) -> None:
        self._actions = actions

        self.accept_suggestions = async_to_streamed_response_wrapper(
            actions.accept_suggestions,
        )
        self.validate = async_to_streamed_response_wrapper(
            actions.validate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.rooms import (
    ActionRefreshClientTokenResponse,
    ActionGenerateJoinClientTokenResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestActions:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_generate_join_client_token(self, client: Telnyx) -> None:
        action = client.rooms.actions.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
        )
        assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_generate_join_client_token_with_all_params(self, client: Telnyx) -> None:
        action = client.rooms.actions.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token_ttl_secs=3600,
            token_ttl_secs=600,
        )
        assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_generate_join_client_token(self, client: Telnyx) -> None:
        response = client.rooms.actions.with_raw_response.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_generate_join_client_token(self, client: Telnyx) -> None:
        with client.rooms.actions.with_streaming_response.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_generate_join_client_token(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `room_id` but received ''"):
            client.rooms.actions.with_raw_response.generate_join_client_token(
                room_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_refresh_client_token(self, client: Telnyx) -> None:
        action = client.rooms.actions.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
        )
        assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_refresh_client_token_with_all_params(self, client: Telnyx) -> None:
        action = client.rooms.actions.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
            token_ttl_secs=600,
        )
        assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_refresh_client_token(self, client: Telnyx) -> None:
        response = client.rooms.actions.with_raw_response.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_refresh_client_token(self, client: Telnyx) -> None:
        with client.rooms.actions.with_streaming_response.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_refresh_client_token(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `room_id` but received ''"):
            client.rooms.actions.with_raw_response.refresh_client_token(
                room_id="",
                refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
            )


class TestAsyncActions:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_generate_join_client_token(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.rooms.actions.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
        )
        assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_generate_join_client_token_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.rooms.actions.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token_ttl_secs=3600,
            token_ttl_secs=600,
        )
        assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_generate_join_client_token(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.rooms.actions.with_raw_response.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_generate_join_client_token(self, async_client: AsyncTelnyx) -> None:
        async with async_client.rooms.actions.with_streaming_response.generate_join_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionGenerateJoinClientTokenResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_generate_join_client_token(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `room_id` but received ''"):
            await async_client.rooms.actions.with_raw_response.generate_join_client_token(
                room_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_refresh_client_token(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.rooms.actions.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
        )
        assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_refresh_client_token_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.rooms.actions.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
            token_ttl_secs=600,
        )
        assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_refresh_client_token(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.rooms.actions.with_raw_response.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_refresh_client_token(self, async_client: AsyncTelnyx) -> None:
        async with async_client.rooms.actions.with_streaming_response.refresh_client_token(
            room_id="0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
            refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRefreshClientTokenResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_refresh_client_token(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `room_id` but received ''"):
            await async_client.rooms.actions.with_raw_response.refresh_client_token(
                room_id="",
                refresh_token="eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJhdWQiOiJ0ZWxueXhfdGVsZXBob255IiwiZXhwIjoxNTkwMDEwMTQzLCJpYXQiOjE1ODc1OTA5NDMsImlzcyI6InRlbG55eF90ZWxlcGhvbnkiLCJqdGkiOiJiOGM3NDgzNy1kODllLTRhNjUtOWNmMi0zNGM3YTZmYTYwYzgiLCJuYmYiOjE1ODc1OTA5NDIsInN1YiI6IjVjN2FjN2QwLWRiNjUtNGYxMS05OGUxLWVlYzBkMWQ1YzZhZSIsInRlbF90b2tlbiI6InJqX1pra1pVT1pNeFpPZk9tTHBFVUIzc2lVN3U2UmpaRmVNOXMtZ2JfeENSNTZXRktGQUppTXlGMlQ2Q0JSbWxoX1N5MGlfbGZ5VDlBSThzRWlmOE1USUlzenl6U2xfYURuRzQ4YU81MHlhSEd1UlNZYlViU1ltOVdJaVEwZz09IiwidHlwIjoiYWNjZXNzIn0.gNEwzTow5MLLPLQENytca7pUN79PmPj6FyqZWW06ZeEmesxYpwKh0xRtA0TzLh6CDYIRHrI8seofOO0YFGDhpQ",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .address import Address
from .._models import BaseModel

__all__ = ["AddressRetrieveResponse"]


class AddressRetrieveResponse(BaseModel):
    data: Optional[Address] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .json import (
    JsonResource,
    AsyncJsonResource,
    JsonResourceWithRawResponse,
    AsyncJsonResourceWithRawResponse,
    JsonResourceWithStreamingResponse,
    AsyncJsonResourceWithStreamingResponse,
)
from .transcriptions import (
    TranscriptionsResource,
    AsyncTranscriptionsResource,
    TranscriptionsResourceWithRawResponse,
    AsyncTranscriptionsResourceWithRawResponse,
    TranscriptionsResourceWithStreamingResponse,
    AsyncTranscriptionsResourceWithStreamingResponse,
)

__all__ = [
    "JsonResource",
    "AsyncJsonResource",
    "JsonResourceWithRawResponse",
    "AsyncJsonResourceWithRawResponse",
    "JsonResourceWithStreamingResponse",
    "AsyncJsonResourceWithStreamingResponse",
    "TranscriptionsResource",
    "AsyncTranscriptionsResource",
    "TranscriptionsResourceWithRawResponse",
    "AsyncTranscriptionsResourceWithRawResponse",
    "TranscriptionsResourceWithStreamingResponse",
    "AsyncTranscriptionsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

from .._types import SequenceNotStr

__all__ = ["MessagingHostedNumberOrderCreateParams"]


class MessagingHostedNumberOrderCreateParams(TypedDict, total=False):
    messaging_profile_id: str
    """
    Automatically associate the number with this messaging profile ID when the order
    is complete.
    """

    phone_numbers: SequenceNotStr[str]
    """Phone numbers to be used for hosted messaging."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .private_wireless_gateway import PrivateWirelessGateway

__all__ = ["PrivateWirelessGatewayCreateResponse"]


class PrivateWirelessGatewayCreateResponse(BaseModel):
    data: Optional[PrivateWirelessGateway] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["CustomerServiceRecordVerifyPhoneNumberCoverageResponse", "Data"]


class Data(BaseModel):
    additional_data_required: Optional[
        List[
            Literal[
                "name",
                "authorized_person_name",
                "account_number",
                "customer_code",
                "pin",
                "address_line_1",
                "city",
                "state",
                "zip_code",
                "billing_phone_number",
            ]
        ]
    ] = None
    """Additional data required to perform CSR for the phone number.

    Only returned if `has_csr_coverage` is true.
    """

    has_csr_coverage: Optional[bool] = None
    """Indicates whether the phone number is covered or not."""

    phone_number: Optional[str] = None
    """The phone number that is being verified."""

    reason: Optional[str] = None
    """The reason why the phone number is not covered.

    Only returned if `has_csr_coverage` is false.
    """

    record_type: Optional[str] = None
    """Identifies the type of the resource."""


class CustomerServiceRecordVerifyPhoneNumberCoverageResponse(BaseModel):
    data: Optional[List[Data]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["UserRetrieveParams"]


class UserRetrieveParams(TypedDict, total=False):
    include_groups: bool
    """When set to true, includes the groups array for each user in the response.

    The groups array contains objects with id and name for each group the user
    belongs to.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .sim_card_status import SimCardStatus as SimCardStatus
from .minimax_voice_settings import MinimaxVoiceSettings as MinimaxVoiceSettings
from .connection_jitter_buffer import ConnectionJitterBuffer as ConnectionJitterBuffer
from .connection_noise_suppression_details import ConnectionNoiseSuppressionDetails as ConnectionNoiseSuppressionDetails



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["WireguardPeerPatch"]


class WireguardPeerPatch(BaseModel):
    public_key: Optional[str] = None
    """
    The WireGuard `PublicKey`.<br /><br />If you do not provide a Public Key, a new
    Public and Private key pair will be generated for you.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["NotificationChannel"]


class NotificationChannel(BaseModel):
    """A Notification Channel"""

    id: Optional[str] = None
    """A UUID."""

    channel_destination: Optional[str] = None
    """The destination associated with the channel type."""

    channel_type_id: Optional[Literal["sms", "voice", "email", "webhook"]] = None
    """A Channel Type ID"""

    created_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the resource was created."""

    notification_profile_id: Optional[str] = None
    """A UUID reference to the associated Notification Profile."""

    updated_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the resource was updated."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["PhoneNumberConfigurationListParams", "Filter", "FilterPortingOrder", "Sort"]


class PhoneNumberConfigurationListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[porting_order.status][in][],
    filter[porting_phone_number][in][], filter[user_bundle_id][in][]
    """

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]

    sort: Sort
    """Consolidated sort parameter (deepObject style). Originally: sort[value]"""


class FilterPortingOrder(TypedDict, total=False):
    status: List[
        Literal[
            "activation-in-progress",
            "cancel-pending",
            "cancelled",
            "draft",
            "exception",
            "foc-date-confirmed",
            "in-process",
            "ported",
            "submitted",
        ]
    ]
    """Filter results by specific porting order statuses"""


class Filter(TypedDict, total=False):
    """Consolidated filter parameter (deepObject style).

    Originally: filter[porting_order.status][in][], filter[porting_phone_number][in][], filter[user_bundle_id][in][]
    """

    porting_order: FilterPortingOrder

    porting_phone_number: SequenceNotStr[str]
    """Filter results by a list of porting phone number IDs"""

    user_bundle_id: SequenceNotStr[str]
    """Filter results by a list of user bundle IDs"""


class Sort(TypedDict, total=False):
    """Consolidated sort parameter (deepObject style). Originally: sort[value]"""

    value: Literal["created_at", "-created_at"]
    """Specifies the sort order for results.

    If not given, results are sorted by created_at in descending order.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import TYPE_CHECKING, Dict, List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from ..shared.api_error import APIError

__all__ = ["ActionValidateResponse", "Data", "DataSuggested"]


class DataSuggested(BaseModel):
    """Provides normalized address when available."""

    administrative_area: Optional[str] = None
    """The locality of the address.

    For US addresses, this corresponds to the state of the address.
    """

    country_code: Optional[str] = None
    """The two-character (ISO 3166-1 alpha-2) country code of the address."""

    extended_address: Optional[str] = None
    """
    Additional street address information about the address such as, but not limited
    to, unit number or apartment number.
    """

    locality: Optional[str] = None
    """The locality of the address.

    For US addresses, this corresponds to the city of the address.
    """

    postal_code: Optional[str] = None
    """The postal code of the address."""

    street_address: Optional[str] = None
    """The primary street address information about the address."""

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]


class Data(BaseModel):
    result: Literal["valid", "invalid"]
    """Indicates whether an address is valid or invalid."""

    suggested: DataSuggested
    """Provides normalized address when available."""

    errors: Optional[List[APIError]] = None

    record_type: Optional[str] = None
    """Identifies the type of the resource."""


class ActionValidateResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["AssistantRetrieveParams"]


class AssistantRetrieveParams(TypedDict, total=False):
    call_control_id: str

    fetch_dynamic_variables_from_webhook: bool

    from_: Annotated[str, PropertyInfo(alias="from")]

    to: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Literal, Required, TypeAlias, TypedDict

__all__ = ["AwsVoiceSettingsParam"]


class AwsVoiceSettingsParamTyped(TypedDict, total=False):
    type: Required[Literal["aws"]]
    """Voice settings provider type"""


AwsVoiceSettingsParam: TypeAlias = Union[AwsVoiceSettingsParamTyped, Dict[str, object]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_upload_file_params import ActionUploadFileParams as ActionUploadFileParams
from .action_upload_file_response import ActionUploadFileResponse as ActionUploadFileResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo
from .tf_verification_status import TfVerificationStatus

__all__ = ["RequestListParams"]


class RequestListParams(TypedDict, total=False):
    page: Required[int]

    page_size: Required[int]
    """Request this many records per page

            This value is automatically clamped if the provided value is too large.
    """

    date_end: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    date_start: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    phone_number: str

    status: TfVerificationStatus
    """Tollfree verification status"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel
from .pagination_meta import PaginationMeta

__all__ = ["PortingOrderRetrieveAllowedFocWindowsResponse", "Data"]


class Data(BaseModel):
    ended_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating the end of the range of foc window"""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    started_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating the start of the range of foc window."""


class PortingOrderRetrieveAllowedFocWindowsResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional

from .._models import BaseModel
from .pagination_meta import PaginationMeta

__all__ = ["WirelessBlocklistValueListResponse", "DataCountry", "DataMcc", "DataPlmn"]


class DataCountry(BaseModel):
    code: str
    """ISO 3166-1 Alpha-2 Country Code."""

    name: str
    """The name of the country."""


class DataMcc(BaseModel):
    code: str
    """Mobile Country Code."""

    name: str
    """The name of the country."""


class DataPlmn(BaseModel):
    code: str
    """Public land mobile network code (MCC + MNC)."""

    name: str
    """The name of the network."""


class WirelessBlocklistValueListResponse(BaseModel):
    data: Union[List[DataCountry], List[DataMcc], List[DataPlmn], None] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.messaging_10dlc.campaign.osr_get_attributes_response import OsrGetAttributesResponse

__all__ = ["OsrResource", "AsyncOsrResource"]


class OsrResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OsrResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return OsrResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OsrResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return OsrResourceWithStreamingResponse(self)

    def get_attributes(
        self,
        campaign_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OsrGetAttributesResponse:
        """
        Get OSR campaign attributes

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not campaign_id:
            raise ValueError(f"Expected a non-empty value for `campaign_id` but received {campaign_id!r}")
        return self._get(
            f"/10dlc/campaign/{campaign_id}/osr/attributes",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OsrGetAttributesResponse,
        )


class AsyncOsrResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOsrResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOsrResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOsrResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncOsrResourceWithStreamingResponse(self)

    async def get_attributes(
        self,
        campaign_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OsrGetAttributesResponse:
        """
        Get OSR campaign attributes

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not campaign_id:
            raise ValueError(f"Expected a non-empty value for `campaign_id` but received {campaign_id!r}")
        return await self._get(
            f"/10dlc/campaign/{campaign_id}/osr/attributes",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OsrGetAttributesResponse,
        )


class OsrResourceWithRawResponse:
    def __init__(self, osr: OsrResource) -> None:
        self._osr = osr

        self.get_attributes = to_raw_response_wrapper(
            osr.get_attributes,
        )


class AsyncOsrResourceWithRawResponse:
    def __init__(self, osr: AsyncOsrResource) -> None:
        self._osr = osr

        self.get_attributes = async_to_raw_response_wrapper(
            osr.get_attributes,
        )


class OsrResourceWithStreamingResponse:
    def __init__(self, osr: OsrResource) -> None:
        self._osr = osr

        self.get_attributes = to_streamed_response_wrapper(
            osr.get_attributes,
        )


class AsyncOsrResourceWithStreamingResponse:
    def __init__(self, osr: AsyncOsrResource) -> None:
        self._osr = osr

        self.get_attributes = async_to_streamed_response_wrapper(
            osr.get_attributes,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    MobilePhoneNumber,
    MobilePhoneNumberUpdateResponse,
    MobilePhoneNumberRetrieveResponse,
)
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMobilePhoneNumbers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        mobile_phone_number = client.mobile_phone_numbers.retrieve(
            "id",
        )
        assert_matches_type(MobilePhoneNumberRetrieveResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.mobile_phone_numbers.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_phone_number = response.parse()
        assert_matches_type(MobilePhoneNumberRetrieveResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.mobile_phone_numbers.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_phone_number = response.parse()
            assert_matches_type(MobilePhoneNumberRetrieveResponse, mobile_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.mobile_phone_numbers.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        mobile_phone_number = client.mobile_phone_numbers.update(
            id="id",
        )
        assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        mobile_phone_number = client.mobile_phone_numbers.update(
            id="id",
            call_forwarding={
                "call_forwarding_enabled": True,
                "forwarding_type": "always",
                "forwards_to": "forwards_to",
            },
            call_recording={
                "inbound_call_recording_channels": "single",
                "inbound_call_recording_enabled": True,
                "inbound_call_recording_format": "wav",
            },
            caller_id_name_enabled=True,
            cnam_listing={
                "cnam_listing_details": "cnam_listing_details",
                "cnam_listing_enabled": True,
            },
            connection_id="connection_id",
            customer_reference="customer_reference",
            inbound={"interception_app_id": "interception_app_id"},
            inbound_call_screening="disabled",
            noise_suppression=True,
            outbound={"interception_app_id": "interception_app_id"},
            tags=["string"],
        )
        assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.mobile_phone_numbers.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_phone_number = response.parse()
        assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.mobile_phone_numbers.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_phone_number = response.parse()
            assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.mobile_phone_numbers.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        mobile_phone_number = client.mobile_phone_numbers.list()
        assert_matches_type(SyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        mobile_phone_number = client.mobile_phone_numbers.list(
            page_number=0,
            page_size=0,
        )
        assert_matches_type(SyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.mobile_phone_numbers.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_phone_number = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.mobile_phone_numbers.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_phone_number = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncMobilePhoneNumbers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        mobile_phone_number = await async_client.mobile_phone_numbers.retrieve(
            "id",
        )
        assert_matches_type(MobilePhoneNumberRetrieveResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_phone_numbers.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_phone_number = await response.parse()
        assert_matches_type(MobilePhoneNumberRetrieveResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_phone_numbers.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_phone_number = await response.parse()
            assert_matches_type(MobilePhoneNumberRetrieveResponse, mobile_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.mobile_phone_numbers.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        mobile_phone_number = await async_client.mobile_phone_numbers.update(
            id="id",
        )
        assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mobile_phone_number = await async_client.mobile_phone_numbers.update(
            id="id",
            call_forwarding={
                "call_forwarding_enabled": True,
                "forwarding_type": "always",
                "forwards_to": "forwards_to",
            },
            call_recording={
                "inbound_call_recording_channels": "single",
                "inbound_call_recording_enabled": True,
                "inbound_call_recording_format": "wav",
            },
            caller_id_name_enabled=True,
            cnam_listing={
                "cnam_listing_details": "cnam_listing_details",
                "cnam_listing_enabled": True,
            },
            connection_id="connection_id",
            customer_reference="customer_reference",
            inbound={"interception_app_id": "interception_app_id"},
            inbound_call_screening="disabled",
            noise_suppression=True,
            outbound={"interception_app_id": "interception_app_id"},
            tags=["string"],
        )
        assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_phone_numbers.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_phone_number = await response.parse()
        assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_phone_numbers.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_phone_number = await response.parse()
            assert_matches_type(MobilePhoneNumberUpdateResponse, mobile_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.mobile_phone_numbers.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        mobile_phone_number = await async_client.mobile_phone_numbers.list()
        assert_matches_type(AsyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mobile_phone_number = await async_client.mobile_phone_numbers.list(
            page_number=0,
            page_size=0,
        )
        assert_matches_type(AsyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.mobile_phone_numbers.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mobile_phone_number = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.mobile_phone_numbers.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mobile_phone_number = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[MobilePhoneNumber], mobile_phone_number, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .embedding_create_embeddings_params import EmbeddingCreateEmbeddingsParams as EmbeddingCreateEmbeddingsParams
from .embedding_create_embeddings_response import EmbeddingCreateEmbeddingsResponse as EmbeddingCreateEmbeddingsResponse
from .embedding_list_embedding_models_response import (
    EmbeddingListEmbeddingModelsResponse as EmbeddingListEmbeddingModelsResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["RcInviteTestNumberResponse", "Data"]


class Data(BaseModel):
    agent_id: Optional[str] = None
    """RCS agent ID"""

    phone_number: Optional[str] = None
    """Phone number that was invited for testing"""

    record_type: Optional[Literal["rcs.test_number_invite"]] = None
    """Identifies the type of the resource"""

    status: Optional[str] = None
    """Status of the test number invitation"""


class RcInviteTestNumberResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["VirtualCrossConnectsCoverageListResponse", "Location"]


class Location(BaseModel):
    code: Optional[str] = None
    """Location code."""

    name: Optional[str] = None
    """Human readable name of location."""

    pop: Optional[str] = None
    """Point of presence of location."""

    region: Optional[str] = None
    """Identifies the geographical region of location."""

    site: Optional[str] = None
    """Site of location."""


class VirtualCrossConnectsCoverageListResponse(BaseModel):
    available_bandwidth: Optional[List[float]] = None
    """
    The available throughput in Megabits per Second (Mbps) for your Virtual Cross
    Connect.
    """

    cloud_provider: Optional[Literal["aws", "azure", "gce"]] = None
    """
    The Virtual Private Cloud with which you would like to establish a cross
    connect.
    """

    cloud_provider_region: Optional[str] = None
    """The region where your Virtual Private Cloud hosts are located.

    Should be identical to how the cloud provider names region, i.e. us-east-1 for
    AWS but Frankfurt for Azure
    """

    location: Optional[Location] = None

    record_type: Optional[str] = None
    """Identifies the type of the resource."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["Vertical"]

Vertical: TypeAlias = Literal[
    "REAL_ESTATE",
    "HEALTHCARE",
    "ENERGY",
    "ENTERTAINMENT",
    "RETAIL",
    "AGRICULTURE",
    "INSURANCE",
    "EDUCATION",
    "HOSPITALITY",
    "FINANCIAL",
    "GAMBLING",
    "CONSTRUCTION",
    "NGO",
    "MANUFACTURING",
    "GOVERNMENT",
    "TECHNOLOGY",
    "COMMUNICATION",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ..filter import Filter
from ....._models import BaseModel

__all__ = ["MdrDetailReportResponse"]


class MdrDetailReportResponse(BaseModel):
    id: Optional[str] = None
    """Identifies the resource"""

    connections: Optional[List[int]] = None

    created_at: Optional[datetime] = None

    directions: Optional[List[Literal["INBOUND", "OUTBOUND"]]] = None

    end_date: Optional[datetime] = None

    filters: Optional[List[Filter]] = None

    profiles: Optional[List[str]] = None
    """List of messaging profile IDs"""

    record_type: Optional[str] = None

    record_types: Optional[List[Literal["INCOMPLETE", "COMPLETED", "ERRORS"]]] = None

    report_name: Optional[str] = None

    report_url: Optional[str] = None

    start_date: Optional[datetime] = None

    status: Optional[Literal["PENDING", "COMPLETE", "FAILED", "EXPIRED"]] = None

    updated_at: Optional[datetime] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["NumberLookupRetrieveParams"]


class NumberLookupRetrieveParams(TypedDict, total=False):
    type: Literal["carrier", "caller-name"]
    """Specifies the type of number lookup to be performed"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .conference_participant_speak_ended import ConferenceParticipantSpeakEnded

__all__ = ["ConferenceParticipantSpeakEndedWebhookEvent"]


class ConferenceParticipantSpeakEndedWebhookEvent(BaseModel):
    data: Optional[ConferenceParticipantSpeakEnded] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ConferenceListParticipantsParams", "Filter"]


class ConferenceListParticipantsParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[muted], filter[on_hold], filter[whispering]
    """

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]

    region: Literal["Australia", "Europe", "Middle East", "US"]
    """Region where the conference data is located"""


class Filter(TypedDict, total=False):
    """Consolidated filter parameter (deepObject style).

    Originally: filter[muted], filter[on_hold], filter[whispering]
    """

    muted: bool
    """If present, participants will be filtered to those who are/are not muted"""

    on_hold: bool
    """If present, participants will be filtered to those who are/are not put on hold"""

    whispering: bool
    """
    If present, participants will be filtered to those who are whispering or are not
    """
